==> uedition-1.3.0.tar.gz: uedition-1.3.0/docs/en/user/content.md <==
# Writing Content

The μEdition uses [Jupyter Book](https://jupyterbook.org) as its underlying technology for turning your text into a
publishable website. Each language in the μEdition is a separate Jupyter Book and the μEdition provides the glue that
merges the individual outputs together into a single site. This is achieved by moving the Jupyter Book configuration
into shared configuration files. When the μEdition builds the final website, language-specific versions of the
configurations are added to each language-specific Jupyter Book, before the Jupyter Book build process is then run
for each language. Due to this structure, most of the guidance that the Jupyter Book project provides for writing
and configuring Jupyter Book projects can be used in the μEdition.

## Structuring the μEdition

The structure of the μEdition is defined via its table of contents, which is configured in the {file}`toc.yml` file
in the μEdition root folder. The {file}`toc.yml` file uses the same format as [defined by the Jupyter Book project](https://jupyterbook.org/en/stable/structure/toc.html).
The only difference is that where the standard Jupyter Book table of contents has a single `title` or `caption`,
in the μEdition these entries can contain a mapping of language code to text. When generating the language-specific
table of contents the μEdition ensures that the correct language value is used for the caption or title for that
language:

:::{code-block} yaml
format: jb-book
root: index
parts:
  - caption:
      en: Name of Part 1
      de: Name von Teil 1
    chapters:
    - title:
        en: Chapter 1
        de: Chapter 2
      file: path/to/part1/chapter1
    - file: path/to/part1/chapter2
:::

## Writing text content

Jupter Book primarily uses MyST or Markedly Structured Text for writing text content, which is an extension of Markdown
designed for publishable content. A good overview over the core functionality can be found
[here](https://myst-parser.readthedocs.io/en/latest/syntax/typography.html). Jupyter Book provides a range of extensions
built upon the core MySQ structure, which are documented [here](https://jupyterbook.org/en/stable/content/index.html)
and which include useful things like glossaries, indices, citations, footnotes, plus elements for structuring the layout
of the page and its content.

## Local server

While writing it can be helpful to see what the result will look like. To simplify this, the μEdition provides a built-in
web-server that automatically re-generates the website when you edit the content. To start this server, run the
following command:

:::{code-block} console
$ hatch run serve
:::

This will build the μEdition and then make it available at http://localhost:8000. When you make changes to the content,
the μEdition will automatically re-build the website and automatically reload the view in the browser.

==> uedition-2.0.0b1.tar.gz: uedition-2.0.0b1/docs/en/user/content.md <==
# Writing Content

The μEdition uses [Jupyter Book](https://jupyterbook.org) as its underlying technology for turning your text into a
publishable website. Each language in the μEdition is a separate Jupyter Book and the μEdition provides the glue that
merges the individual outputs together into a single site. This is achieved by moving the Jupyter Book configuration
into shared configuration files. When the μEdition builds the final website, language-specific versions of the
configurations are added to each language-specific Jupyter Book, before the Jupyter Book build process is then run
for each language. Due to this structure, most of the guidance that the Jupyter Book project provides for writing
and configuring Jupyter Book projects can be used in the μEdition.

## Structuring the μEdition

The structure of the μEdition is defined via its table of contents, which is configured in the {file}`toc.yml` file
in the μEdition root folder. The {file}`toc.yml` file uses the same format as [defined by the Jupyter Book project](https://jupyterbook.org/en/stable/structure/toc.html).
The only difference is that where the standard Jupyter Book table of contents has a single `title` or `caption`,
in the μEdition these entries can contain a mapping of language code to text. When generating the language-specific
table of contents the μEdition ensures that the correct language value is used for the caption or title for that
language:

:::{code-block} yaml
format: jb-book
root: index
parts:
  - caption:
      en: Name of Part 1
      de: Name von Teil 1
    chapters:
    - title:
        en: Chapter 1
        de: Chapter 2
      file: path/to/part1/chapter1
    - file: path/to/part1/chapter2
:::

## Writing text content

Jupter Book primarily uses MyST or Markedly Structured Text for writing text content, which is an extension of Markdown
designed for publishable content. A good overview over the core functionality can be found
[here](https://myst-parser.readthedocs.io/en/latest/syntax/typography.html). Jupyter Book provides a range of extensions
built upon the core MyST structure, which are documented [here](https://jupyterbook.org/en/stable/content/index.html)
and which include useful things like glossaries, indices, citations, footnotes, plus elements for structuring the layout
of the page and its content.

## Local server

While writing it can be helpful to see what the result will look like. To simplify this, the μEdition provides a built-in
web-server that automatically re-generates your μEdition when you edit the content. To start this server, run the
following command:

:::{code-block} console
$ hatch run serve
:::

This will build your μEdition and then make it available at http://localhost:8000. When you make changes to the content,
the μEdition will automatically re-build your μEdition and automatically reload the view in the browser.
